# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.task
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from .x_job_listener import XJobListener as XJobListener_af600b74

class XAsyncJob(XInterface_8f010a43):
    """
    specifies a job which must be executed asynchronously
    
    Instead of XJob the implementation of this interface must be aware, that execution can be made real asynchronous (e.g. by using threads). Because the environment wish to have creation and using of threads under control, it's not allowed for a real job implementation to use such mechanism by itself. The outside code decide, if it's possible and how it can be made asynchronous. In some special cases it can be, that asynchronous jobs will be executed synchronously.

    See Also:
        `API XAsyncJob <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XAsyncJob.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.task.XAsyncJob']

    def executeAsync(self, Arguments: 'typing.Tuple[NamedValue_a37a0af3, ...]', Listener: 'XJobListener_af600b74') -> None:
        """
        executes the job asynchronously

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.auth
from .xsso_manager_factory import XSSOManagerFactory as XSSOManagerFactory_f7ef0d9a

class SSOManagerFactory(XSSOManagerFactory_f7ef0d9a):
    """
    Service Class

    represents a starting point for Single Sign-on interactions.
    
    The Single Sign-on ( SSO ) APIs provide UNO based access to underlying SSO implementations ( e.g. Kerberos ). The aim of the SSO APIs is to enable authentication ( possibly mutual ) between a client ( source or initiator ) and a network service ( target or acceptor ). This is achieved via. the creation and processing of security tokens sent between the two parties. The steps which should be followed to successfully use the SSO APIs are as follows:
    
    The interface supports the creation of XSSOManager instances which can subsequently be used to create security contexts.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API SSOManagerFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1auth_1_1SSOManagerFactory.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class RelOrientation(object):
    """
    Const

    These values define the reference position of relative orientations.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API RelOrientation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html>`_
    """
    FRAME: Literal[0]
    """
    paragraph, including margins
    """
    PRINT_AREA: Literal[1]
    """
    paragraph, without margins
    """
    CHAR: Literal[2]
    """
    at a character
    """
    PAGE_LEFT: Literal[3]
    """
    inside the left page margin
    """
    PAGE_RIGHT: Literal[4]
    """
    inside the right page margin
    """
    FRAME_LEFT: Literal[5]
    """
    inside the left paragraph margin
    """
    FRAME_RIGHT: Literal[6]
    """
    inside the right paragraph margin
    """
    PAGE_FRAME: Literal[7]
    """
    page includes margins for page-anchored frames identical with RelOrientation.FRAME
    """
    PAGE_PRINT_AREA: Literal[8]
    """
    page without borders (for page anchored frames identical with RelOrientation.PRINT_AREA).
    """
    TEXT_LINE: Literal[9]
    """
    at the top of the text line, only sensible for vertical orientation.
    
    **since**
    
        OOo 2.0
    """
    PAGE_PRINT_AREA_BOTTOM: Literal[10]
    """
    Bottom page border (page area below PAGE_PRINT_AREA).
    
    **since**
    
        LibreOffice 7.0
    """
    PAGE_PRINT_AREA_TOP: Literal[11]
    """
    Top page border (page area above PAGE_PRINT_AREA).
    
    **since**
    
        LibreOffice 7.1
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.lang
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XInitialization(XInterface_8f010a43):
    """
    initializes an object directly after its creation.
    
    This interface works together with factories. If you want to initialize the object after creation, you should support this interface and you may support other interfaces which offer type-safe initialization methods.
    
    Instead of calling XSingleComponentFactory.createInstanceWithContext() and later initialize(), you should call XSingleComponentFactory.createInstanceWithArgumentsAndContext() to pass the arguments to the instance. The reason is, that a component may want to return the same instance for the same set of parameters, and it can do so by implementing the factory itself.

    See Also:
        `API XInitialization <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XInitialization.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.lang.XInitialization']

    def initialize(self, aArguments: 'typing.Tuple[object, ...]') -> None:
        """
        initializes the object.
        
        It should be called directly after the object is created.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_title import XTitle as XTitle_833f09a6
    from ..drawing.rectangle_point import RectanglePoint as RectanglePoint_f0ff0d93

class XLabeled(ABC):
    """

    See Also:
        `API XLabeled <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XLabeled.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XLabeled']

    def getLabel(self) -> 'XTitle_833f09a6':
        """
        """
    def getLabelAnchor(self) -> 'RectanglePoint_f0ff0d93':
        """
        """
    def getOffset(self) -> 'typing.Tuple[float, ...]':
        """
        """
    def getOwnAnchor(self) -> 'RectanglePoint_f0ff0d93':
        """
        """
    def setLabel(self, xTitle: 'XTitle_833f09a6') -> None:
        """
        """
    def setLabelAnchor(self, aAnchorPoint: 'RectanglePoint_f0ff0d93') -> None:
        """
        """
    def setOffset(self, aOffsetVector: 'typing.Tuple[float, ...]') -> None:
        """
        """
    def setOwnAnchor(self, aAnchorPoint: 'RectanglePoint_f0ff0d93') -> None:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XConstantTypeDescription(XTypeDescription_3c210fb1):
    """
    Reflects a constant.
    
    The type class of this type is com.sun.star.uno.TypeClass.CONSTANT.
    
    Constants may be contained in constants groups and modules.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XConstantTypeDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XConstantTypeDescription.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XConstantTypeDescription']

    def getConstantValue(self) -> object:
        """
        Following types are allowed for constants:
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal


class ShadingPattern(object):
    """
    Const

    The ShadingPattern determines the background color pattern against which characters and graphics are displayed, typically in tables.
    
    The color can be no color or it can be a specific color with a transparency or pattern value.

    See Also:
        `API ShadingPattern <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1ShadingPattern.html>`_
    """
    CLEAR: Literal[0]
    SOLID: Literal[1]
    PCT5: Literal[2]
    PCT10: Literal[3]
    PCT20: Literal[4]
    PCT25: Literal[5]
    PCT30: Literal[6]
    PCT40: Literal[7]
    PCT50: Literal[8]
    PCT60: Literal[9]
    PCT70: Literal[10]
    PCT75: Literal[11]
    PCT80: Literal[12]
    PCT90: Literal[13]
    HORZ_STRIPE: Literal[14]
    VERT_STRIPE: Literal[15]
    REVERSE_DIAG_STRIPE: Literal[16]
    DIAG_STRIPE: Literal[17]
    HORZ_CROSS: Literal[18]
    DIAG_CROSS: Literal[19]
    THIN_HORZ_STRIPE: Literal[20]
    THIN_VERT_STRIPE: Literal[21]
    THIN_REVERSE_DIAG_STRIPE: Literal[22]
    THIN_DIAG_STRIPE: Literal[23]
    THIN_HORZ_CROSS: Literal[24]
    THIN_DIAG_CROSS: Literal[25]
    UNUSED_1: Literal[26]
    UNUSED_2: Literal[27]
    UNUSED_3: Literal[28]
    UNUSED_4: Literal[29]
    UNUSED_5: Literal[30]
    UNUSED_6: Literal[31]
    UNUSED_7: Literal[32]
    UNUSED_8: Literal[33]
    UNUSED_9: Literal[34]
    PCT2: Literal[35]
    PCT7: Literal[36]
    PCT12: Literal[37]
    PCT15: Literal[38]
    PCT17: Literal[39]
    PCT22: Literal[40]
    PCT27: Literal[41]
    PCT32: Literal[42]
    PCT35: Literal[43]
    PCT37: Literal[44]
    PCT42: Literal[45]
    PCT45: Literal[46]
    PCT47: Literal[47]
    PCT52: Literal[48]
    PCT55: Literal[49]
    PCT57: Literal[50]
    PCT62: Literal[51]
    PCT65: Literal[52]
    PCT67: Literal[53]
    PCT72: Literal[54]
    PCT77: Literal[55]
    PCT82: Literal[56]
    PCT85: Literal[57]
    PCT87: Literal[58]
    PCT92: Literal[59]
    PCT95: Literal[60]
    PCT97: Literal[61]
    NIL: Literal[65535]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b

class XAccessible(XInterface_8f010a43):
    """
    This interface has to be implemented by any class that wants to be accessible.
    
    It is used to provide access to the XAccessibleContext interface but allows at the same time that the interface is implemented by another class.
    
    The distinction between the interfaces XAccessible and XAccessibleContext makes it possible to split up the implementation of the class that is made accessible and the actual accessibility code into two (mostly) independent parts. The only necessary dependence is the XAccessible.getAccessibleContext() function that returns the accessible context. This one-way link has to be persistent in some sense: As long as there is at least one reference to a specific XAccessibleContext object the XAccessible object has to return the same context for every call to XAccessible.getAccessibleContext(). This is necessary to allow the use of object identity for comparing accessibility contexts for being equal.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessible <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessible.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessible']

    def getAccessibleContext(self) -> 'XAccessibleContext_8eae119b':
        """
        Returns the AccessibleContext associated with this object.
        
        The idea to let this interface only return an XAccessibleContext instead of directly supporting its functions is to allow the separation of the implementation of the functions that make a class accessible from the implementation of that class. You may, of course, implement XAccessible and XAccessibleContext in one class.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
"""
Const

These constants specify the interpolation type for animation frames.

With this constants, one specifies the way of interpolation that takes place between two consecutive frames of a discrete animation sequence.

**since**

    OOo 2.0

See Also:
    `API InterpolationMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1InterpolationMode.html>`_
"""
NEAREST_NEIGHBOR: Literal[1]
"""
Perform a nearest neighbor interpolation.

That is, when interpolating between two values v0 and v1, positioned at t0 and t1, take the one which has the closest t coordinate.
"""
LINEAR: Literal[2]
"""
Perform a linear interpolation.

That is, when interpolating at position t between two values v0 and v1, positioned at t0 and t1, take the sum of v0 weighted with (t-t0) and v1 weighted with (t1-t).
"""
CUBIC: Literal[3]
"""
Perform a cubic interpolation.

That is, when interpolating at position t, take the four closest data points v0, v1, v2, and v3, fit a cubic curve through them, and take the interpolated value from this cubic curve.
"""
BEZIERSPLINE3: Literal[4]
"""
Perform a cubic Bezier spline interpolation.

That is, when interpolating at position t, take the three closest data points v0, v1, and v2, fit a cubic Bezier spline through them, and take the interpolated value from this cubic curve.
"""
BEZIERSPLINE4: Literal[5]
"""
Perform a quadric Bezier spline interpolation.

That is, when interpolating at position t, take the four closest data points v0, v1, v2, and v3, fit a quadric Bezier spline through them, and take the interpolated value from this quadric curve.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from ..sdbc.x_driver_manager import XDriverManager as XDriverManager_c6470c23
if typing.TYPE_CHECKING:
    from .x_database_access import XDatabaseAccess as XDatabaseAccess_c47a0c00

class XDatabaseEnvironment(XDriverManager_c6470c23):
    """
    is not to be used anymore.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDatabaseEnvironment <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseEnvironment.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XDatabaseEnvironment']

    def createDatabaseAccess(self, URL: str, title: str) -> 'XDatabaseAccess_c47a0c00':
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getDatabaseAccess(self, URL: str) -> 'XDatabaseAccess_c47a0c00':
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..drawing.direction3_d import Direction3D as Direction3D_c9370c0c


class LightSource(object):
    """
    Struct Class


    See Also:
        `API LightSource <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart2_1_1LightSource.html>`_
    """
    typeName: Literal['com.sun.star.chart2.LightSource']

    def __init__(self, nDiffuseColor: typing.Optional[int] = ..., aDirection: typing.Optional[Direction3D_c9370c0c] = ..., bIsEnabled: typing.Optional[bool] = ..., bSpecular: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            nDiffuseColor (int, optional): nDiffuseColor value.
            aDirection (Direction3D, optional): aDirection value.
            bIsEnabled (bool, optional): bIsEnabled value.
            bSpecular (bool, optional): bSpecular value.
        """


    @property
    def nDiffuseColor(self) -> int:
        """
        the light source's color
        """


    @property
    def aDirection(self) -> Direction3D_c9370c0c:
        """
        the direction into which the light-source points
        """


    @property
    def bIsEnabled(self) -> bool:
        ...


    @property
    def bSpecular(self) -> bool:
        """
        When TRUE, the specularity of material is taken into account when lighting an object.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart
from typing_extensions import Literal
import typing
from .x_chart_data import XChartData as XChartData_a3580ade

class XChartDataArray(XChartData_a3580ade):
    """
    gives access to data represented as an array of rows.
    
    Can be obtained from interface XChartDocument via method getData().
    
    If used for an XYDiagram, the row number 0 represents the x-values.

    See Also:
        `API XChartDataArray <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XChartDataArray.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart.XChartDataArray']

    def getColumnDescriptions(self) -> 'typing.Tuple[str, ...]':
        """
        retrieves the description texts for all columns.
        """
    def getData(self) -> 'typing.Tuple[typing.Tuple[float, ...], ...]':
        """
        retrieves the numerical data as a nested sequence of values.
        """
    def getRowDescriptions(self) -> 'typing.Tuple[str, ...]':
        """
        retrieves the description texts for all rows.
        """
    def setColumnDescriptions(self, aColumnDescriptions: 'typing.Tuple[str, ...]') -> None:
        """
        sets the description texts for all columns.
        """
    def setData(self, aData: 'typing.Tuple[typing.Tuple[float, ...], ...]') -> None:
        """
        sets the chart data as an array of numbers.
        """
    def setRowDescriptions(self, aRowDescriptions: 'typing.Tuple[str, ...]') -> None:
        """
        sets the description texts for all rows.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from .x_data_pilot_field import XDataPilotField as XDataPilotField_e0350cdf


class DataPilotFieldGroupInfo(object):
    """
    Struct Class

    contains the grouping information of a DataPilotField.

    See Also:
        `API DataPilotFieldGroupInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldGroupInfo.html>`_
    """
    typeName: Literal['com.sun.star.sheet.DataPilotFieldGroupInfo']

    def __init__(self, HasAutoStart: typing.Optional[bool] = ..., HasAutoEnd: typing.Optional[bool] = ..., HasDateValues: typing.Optional[bool] = ..., Start: typing.Optional[float] = ..., End: typing.Optional[float] = ..., Step: typing.Optional[float] = ..., GroupBy: typing.Optional[int] = ..., SourceField: typing.Optional[XDataPilotField_e0350cdf] = ..., Groups: typing.Optional[XNameAccess_e2ab0cf6] = ...) -> None:
        """
        Constructor

        Arguments:
            HasAutoStart (bool, optional): HasAutoStart value.
            HasAutoEnd (bool, optional): HasAutoEnd value.
            HasDateValues (bool, optional): HasDateValues value.
            Start (float, optional): Start value.
            End (float, optional): End value.
            Step (float, optional): Step value.
            GroupBy (int, optional): GroupBy value.
            SourceField (XDataPilotField, optional): SourceField value.
            Groups (XNameAccess, optional): Groups value.
        """


    @property
    def HasAutoStart(self) -> bool:
        """
        specifies whether the start value for the grouping is taken automatically from the minimum of the item values.
        """


    @property
    def HasAutoEnd(self) -> bool:
        """
        specifies whether the end value for the grouping is taken automatically from the maximum of the item values.
        """


    @property
    def HasDateValues(self) -> bool:
        """
        specifies whether date values are grouped by ranges of days.
        """


    @property
    def Start(self) -> float:
        """
        specifies the start value for the grouping if HasAutoStart is set to FALSE.
        """


    @property
    def End(self) -> float:
        """
        specifies the end value for the grouping if HasAutoEnd is set to FALSE.
        """


    @property
    def Step(self) -> float:
        """
        specifies the size of the ranges for numeric or day grouping.
        
        Example: With HasAutoStart set to FALSE, Start set to 2, and Step set to 3, the first group will contain all values greater than or equal to 2 and less than 5. The second group will contain all values greater than or equal to 5 and less than 8, and so on.
        """


    @property
    def GroupBy(self) -> int:
        """
        specifies the grouping of the date values.
        """


    @property
    def SourceField(self) -> XDataPilotField_e0350cdf:
        """
        contains the source DataPilot field grouping is based on.
        
        Will be NULL if this field is not grouped or contains numeric grouping.
        """


    @property
    def Groups(self) -> XNameAccess_e2ab0cf6:
        """
        specifies the named groups in this field if there are some.
        
        The returned object is an instance of DataPilotFieldGroups . The collection of groups can be modified by inserting, removing, replacing, or renaming single groups or item names in the groups. When writing back this struct containing such a changed collection of groups to the DataPilotField.GroupInfo property, the modified grouping settings are applied at the DataPilot field.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.tree
from typing_extensions import Literal
import typing
from .x_tree_data_model import XTreeDataModel as XTreeDataModel_f9fc0d85
if typing.TYPE_CHECKING:
    from .x_mutable_tree_node import XMutableTreeNode as XMutableTreeNode_17d80e6a

class XMutableTreeDataModel(XTreeDataModel_f9fc0d85):
    """
    This is the editable version of the XTreeDataModel.
    
    Note that only XTreeNode created from the same instance with createNode() are valid nodes for this instance.

    See Also:
        `API XMutableTreeDataModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XMutableTreeDataModel.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.tree.XMutableTreeDataModel']

    def createNode(self, DisplayValue: object, ChildrenOnDemand: bool) -> 'XMutableTreeNode_17d80e6a':
        """
        creates a new tree node with the given value and given settings.
        """
    def setRoot(self, RootNode: 'XMutableTreeNode_17d80e6a') -> None:
        """
        changes the root node of this model to RootNode.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.uno
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class TypeClass(Enum):
    """
    Enum

    

    See Also:
        `API TypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328>`_
    """

    ANY: 'uno.Enum'
    """
    reflecting the any type; anys can carry any UNO value except of any values
    """
    ARRAY: 'uno.Enum'
    """
    Deprecated, UNOIDL does not have an array concept.
    """
    BOOLEAN: 'uno.Enum'
    """
    reflecting the boolean type; true and false
    """
    BYTE: 'uno.Enum'
    """
    reflecting the 8-bit ordinal type
    """
    CHAR: 'uno.Enum'
    """
    reflecting the 16-bit unicode character type
    """
    CONSTANT: 'uno.Enum'
    """
    reflecting constants
    """
    CONSTANTS: 'uno.Enum'
    """
    reflecting constants groups
    """
    DOUBLE: 'uno.Enum'
    """
    reflecting the 64-bit floating point type
    """
    ENUM: 'uno.Enum'
    """
    reflecting enum types
    """
    EXCEPTION: 'uno.Enum'
    """
    reflecting exception types
    """
    FLOAT: 'uno.Enum'
    """
    reflecting the 32-bit floating point type
    """
    HYPER: 'uno.Enum'
    """
    reflecting the signed 64-bit ordinal type
    """
    INTERFACE: 'uno.Enum'
    """
    reflecting interface types
    """
    INTERFACE_ATTRIBUTE: 'uno.Enum'
    """
    reflecting interface attributes
    """
    INTERFACE_METHOD: 'uno.Enum'
    """
    reflecting interface methods
    """
    LONG: 'uno.Enum'
    """
    reflecting the signed 32-bit ordinal type
    """
    MODULE: 'uno.Enum'
    """
    reflecting modules
    """
    PROPERTY: 'uno.Enum'
    """
    reflecting properties
    """
    SEQUENCE: 'uno.Enum'
    """
    reflecting sequence types
    """
    SERVICE: 'uno.Enum'
    """
    reflecting services
    """
    SHORT: 'uno.Enum'
    """
    reflecting the signed 16-bit ordinal type
    """
    SINGLETON: 'uno.Enum'
    """
    reflecting singletons
    """
    STRING: 'uno.Enum'
    """
    reflecting the string type; strings of unicode characters
    """
    STRUCT: 'uno.Enum'
    """
    reflecting compound types
    """
    TYPE: 'uno.Enum'
    """
    reflecting the meta type
    """
    TYPEDEF: 'uno.Enum'
    """
    reflecting typedefed types referencing other types
    """
    UNION: 'uno.Enum'
    """
    Deprecated, UNOIDL does not have a union concept.
    """
    UNKNOWN: 'uno.Enum'
    """
    reflecting the unreflectable type
    """
    UNSIGNED_HYPER: 'uno.Enum'
    """
    reflecting the unsigned 64-bit ordinal type
    """
    UNSIGNED_LONG: 'uno.Enum'
    """
    reflecting the unsigned 32-bit type
    """
    UNSIGNED_SHORT: 'uno.Enum'
    """
    reflecting the unsigned 16-bit ordinal type
    """
    VOID: 'uno.Enum'
    """
    reflecting the void type; denotes no type
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.uno
from typing_extensions import Literal
import typing
from .x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.x_multi_component_factory import XMultiComponentFactory as XMultiComponentFactory_381b0f98

class XComponentContext(XInterface_8f010a43):
    """
    Component context to be passed to a component via com.sun.star.lang.XSingleComponentFactory.
    
    Arbitrary values (e.g. deployment values) can be retrieved from the context.

    See Also:
        `API XComponentContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XComponentContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.uno.XComponentContext']

    def getServiceManager(self) -> 'XMultiComponentFactory_381b0f98':
        """
        Gets the service manager instance to be used from key /singletons/com.sun.star.lang.theServiceManager.
        
        This method has been added for convenience, because the service manager is used very often.
        """
    def getValueByName(self, Name: str) -> object:
        """
        Gets a value from the context.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..uno.x_aggregation import XAggregation as XAggregation_a4230b1a

class XProxyFactory(XInterface_8f010a43):
    """
    Factory interface to produce proxy objects.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XProxyFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XProxyFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XProxyFactory']

    def createProxy(self, xTarget: 'XInterface_8f010a43') -> 'XAggregation_a4230b1a':
        """
        This method creates a new proxy object that acts on behalf of the given target object.
        
        The proxy delegates calls to the given target object. In addition, it is aggregatable, thus it is possible to intercept calls on the proxy's interfaces.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
from .x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b

class XAccessibleContext2(XAccessibleContext_8eae119b):
    """
    Implement this interface for exposing more aspects of a class's content.
    
    This is an extension of XAccessibleContext to add getAccessibleId().
    
    **since**
    
        LibreOffice 6.3

    See Also:
        `API XAccessibleContext2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleContext2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleContext2']

    def getAccessibleId(self) -> str:
        """
        Return the object's identifier.
        
        This is not meant to be presented to the user, but to be an ID which is stable over application development. Typically, this is the gtkbuilder ID. Such an ID can then be used to identify a given well-known accessible object independently from the current locale, user-visible labelling, or dialog structure. This can then be used for tailored screen reading (e.g. automatically announcing the content of a well-known object), or for automatic regression testing (to check the behavior of well-known objects). Uniqueness within the window is thus desirable when returning a non-empty string.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.view
from typing_extensions import Literal
"""
Const

These constants specify how the document content is zoomed into the document view.

See Also:
    `API DocumentZoomType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1view_1_1DocumentZoomType.html>`_
"""
OPTIMAL: Literal[0]
"""
The page content width (excluding margins) at the current selection is fit into the view.
"""
PAGE_WIDTH: Literal[1]
"""
The page width at the current selection is fit into the view.
"""
ENTIRE_PAGE: Literal[2]
"""
A complete page of the document is fit into the view.
"""
BY_VALUE: Literal[3]
"""
The zoom is relative and is to be set via the property ViewSettings.ZoomValue.
"""
PAGE_WIDTH_EXACT: Literal[4]
"""
The page width at the current selection is fit into the view, with the view ends exactly at the end of the page.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_data_pilot_field import XDataPilotField as XDataPilotField_e0350cdf

class XDataPilotDataLayoutFieldSupplier(ABC):
    """
    Provides access to the DataPilotField used to layout multiple data fields.
    
    This data field can be inserted into the rows dimension or columns dimension by changing its DataPilotField.Orientation property. This interface can be used to access the data layout field before multiple data fields are inserted into the DataPilot table. It remains invisible as long as the DataPilot table contains at most one data field.

    See Also:
        `API XDataPilotDataLayoutFieldSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotDataLayoutFieldSupplier.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XDataPilotDataLayoutFieldSupplier']

    def getDataLayoutField(self) -> 'XDataPilotField_e0350cdf':
        """
        Returns the DataPilotField used to layout multiple data fields.
        
        If the field does not exist yet, it will be created. It is possible to insert this field into the rows or columns dimension by changing its DataPilotField.Orientation property.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from .x_status_listener import XStatusListener as XStatusListener_e2740d35
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..util.x_updatable import XUpdatable as XUpdatable_9a420ab0
if typing.TYPE_CHECKING:
    from ..awt.mouse_event import MouseEvent as MouseEvent_8f430a5f
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9
    from ..awt.x_graphics import XGraphics as XGraphics_842309dd

class XStatusbarController(XStatusListener_e2740d35, XComponent_98dc0ab5, XInitialization_d46c0cca, XUpdatable_9a420ab0):
    """
    interface to be implemented by a component offering a more complex user interface to users within a status bar.
    
    A generic status bar field is represented as a simple text field. A status bar controller can be added to a Statusbar and provide information or functions with a more sophisticated user interface.
    A typical example for status bar controller is a zoom chooser. It shows the current zoom and provides general zoom levels on a pop-up menu that can be activated by a mouse action for context menus.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XStatusbarController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XStatusbarController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XStatusbarController']

    def click(self, aPos: 'Point_5fb2085e') -> None:
        """
        is called by a status bar if the user clicked with mouse into the field of the corresponding control.
        """
    def command(self, aPos: 'Point_5fb2085e', nCommand: int, bMouseEvent: bool, aData: object) -> None:
        """
        is called by a status bar if a command event is available for a controller.
        """
    def doubleClick(self, aPos: 'Point_5fb2085e') -> None:
        """
        is called by a status bar if the user double-clicked with mouse into the field of the corresponding control.
        """
    def mouseButtonDown(self, aMouseEvent: 'MouseEvent_8f430a5f') -> bool:
        """
        is called by a status bar if the mouse position is within the controller and a mouse button has been pressed.
        
        If the controller has captured the mouse input this function is also called when the mouse position is not within the controller.
        """
    def mouseButtonUp(self, aMouseEvent: 'MouseEvent_8f430a5f') -> bool:
        """
        is called by a status bar if the mouse position is within the controller and a mouse button has been released.
        
        If the controller has captured the mouse input this function is also called when the mouse position is not within the controller.
        """
    def mouseMove(self, aMouseEvent: 'MouseEvent_8f430a5f') -> bool:
        """
        is called by a status bar if the mouse position is within the controller and a mouse has been moved.
        
        If the controller has captured the mouse input this function is also called when the mouse position is not within the controller.
        """
    def paint(self, xGraphics: 'XGraphics_842309dd', OutputRectangle: 'Rectangle_84b109e9', nStyle: int) -> None:
        """
        is called by a status bar if the controller has to update the visual representation.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.io
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XMarkableStream(XInterface_8f010a43):
    """
    makes it possible to set and remove seekable marks to a stream.

    See Also:
        `API XMarkableStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.io.XMarkableStream']

    def createMark(self) -> int:
        """
        creates a mark of the current position and returns an identifier to it.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def deleteMark(self, Mark: int) -> None:
        """
        deletes the mark that you previously created with XMarkableStream.createMark().
        
        It is an error to delete a mark if other marks after this exist. In this case, for reasons of robustness, the implementation must delete this mark and all others after this mark.

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def jumpToFurthest(self) -> None:
        """
        jumps to the furthest position of the stream.
        
        In the inputstream case, a subsequent read call returns data, that was never read or skipped over before. In the outputstream case, a subsequent write call will add new data at the end of the stream without overwriting existing data.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def jumpToMark(self, nMark: int) -> None:
        """
        jumps to a previously created mark.

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def offsetToMark(self, nMark: int) -> int:
        """

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_close_listener import XCloseListener as XCloseListener_c8a60c5a

class XCloseBroadcaster(XInterface_8f010a43):
    """
    broadcasts each tried closing of an object to all interest listener
    
    The called object for closing must post the closing events immediately and before any internal cancel operations will be started. If a listener disagree with that it should throw a CloseVetoException and called function XCloseable.close() must be broken immediately. It's not allowed to catch it inside the close() request. If no listener nor internal processes hinder the object on closing all listeners get a notification about real closing.

    See Also:
        `API XCloseBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XCloseBroadcaster.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XCloseBroadcaster']

    def addCloseListener(self, Listener: 'XCloseListener_c8a60c5a') -> None:
        """
        adds the specified listener to receive or have a veto for \"close\" events
        """
    def removeCloseListener(self, Listener: 'XCloseListener_c8a60c5a') -> None:
        """
        removes the specified listener
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..beans.x_property_state import XPropertyState as XPropertyState_d55c0ccf
from ..container.x_named import XNamed as XNamed_a6520b08
from .text_content import TextContent as TextContent_a6810b4d
from .x_text_section import XTextSection as XTextSection_b1730b9f
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..style.graphic_location import GraphicLocation as GraphicLocation_e3ef0d30
    from .section_file_link import SectionFileLink as SectionFileLink_d63e0cb0
    from .x_text_columns import XTextColumns as XTextColumns_b17f0bab

class TextSection(TextContent_a6810b4d, UserDefinedAttributesSupplier_9fbe1222, XPropertySet_bc180bfa, XPropertyState_d55c0ccf, XNamed_a6520b08, XTextSection_b1730b9f):
    """
    Service Class

    A TextSection is a range of complete paragraphs within a text.
    
    The content of the section may be the content of a link into another document, a link from the same document, or the result of a DDE operation.
    
    TextSection instances can be linked from and to other texts.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API TextSection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html>`_
    """
    @property
    def BackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic of the background.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def BackGraphicFilter(self) -> str:
        """
        contains the name of the file filter for the background graphic.
        """
    @property
    def BackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        determines the position of the background graphic.
        """
    @property
    def BackGraphicURL(self) -> str:
        """
        contains the URL for the background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
    @property
    def Condition(self) -> str:
        """
        This property contains a conditional expression.
        
        If the result of the conditional expression is TRUE and the property TextSection.IsVisible is FALSE, then the section is hidden.
        """
    @property
    def DDECommandElement(self) -> str:
        """
        specifies the source element of the command string for a DDE operation.
        
        The element can be i.e. a name of a cell in a sheet or a bookmark.
        """
    @property
    def DDECommandFile(self) -> str:
        """
        specifies the source file name of the command string for a DDE operation.
        """
    @property
    def DDECommandType(self) -> str:
        """
        specifies the type of the command string for a DDE operation.
        
        The type can be the name of the application that provides a DDE source.
        """
    @property
    def EndnoteIsCollectAtTextEnd(self) -> bool:
        """
        determines whether endnotes inside the section are displayed at the end of the section text.
        """
    @property
    def EndnoteIsOwnNumbering(self) -> bool:
        """
        determines whether the endnotes within the section use an own numbering format.
        
        This is only valid if EndnoteIsRestartNumbering is set.
        """
    @property
    def EndnoteIsRestartNumbering(self) -> bool:
        """
        determines whether the endnotes numbering restarts within the section.
        
        This is only valid if EndnoteIsRestartNumbering is set.
        """
    @property
    def EndnoteNumberingPrefix(self) -> str:
        """
        determines the prefix that is display before the endnote number.
        
        This is only valid if EndnoteIsOwnNumbering is set.
        """
    @property
    def EndnoteNumberingSuffix(self) -> str:
        """
        determines the suffix that is display after the endnote number.
        
        This is only valid if EndnoteIsOwnNumbering is set.
        """
    @property
    def EndnoteNumberingType(self) -> int:
        """
        determines the numbering type of the endnote numbering as a value of com.sun.star.style.NumberingType.
        
        This is only valid if EndoteIsOwnNumbering is set.
        """
    @property
    def EndnoteRestartNumberingAt(self) -> int:
        """
        determines at which number the endnote numbering inside of the section starts.
        
        This is only valid if EndnoteIsRestartNumbering is set.
        """
    @property
    def FileLink(self) -> 'SectionFileLink_d63e0cb0':
        """
        If this property is set, then the content of the section is read from the specified document.
        """
    @property
    def FootnoteIsCollectAtTextEnd(self) -> bool:
        """
        determines whether footnotes inside the section are displayed at the end of the section text.
        """
    @property
    def FootnoteIsOwnNumbering(self) -> bool:
        """
        determines whether the footnotes within the section use an own numbering format.
        
        This is only valid if FootnoteIsRestartNumbering is set.
        """
    @property
    def FootnoteIsRestartNumbering(self) -> bool:
        """
        determines whether the footnotes numbering restarts within the section.
        
        This is only valid if FootnoteIsRestartNumbering is set.
        """
    @property
    def FootnoteNumberingPrefix(self) -> str:
        """
        determines the prefix that is display before the footnote number.
        
        This is only valid if FootnoteIsOwnNumbering is set.
        """
    @property
    def FootnoteNumberingSuffix(self) -> str:
        """
        determines the suffix that is display after of the footnote number.
        
        This is only valid if FootnoteIsOwnNumbering is set.
        """
    @property
    def FootnoteNumberingType(self) -> int:
        """
        determines the numbering type of the footnote numbering as a value of com.sun.star.style.NumberingType.
        
        This is only valid if FootnoteIsOwnNumbering is set.
        """
    @property
    def FootnoteRestartNumberingAt(self) -> int:
        """
        determines at which number the footnote numbering inside of the section starts.
        
        This is only valid if FootnoteIsRestartNumbering is set.
        """
    @property
    def IsAutomaticUpdate(self) -> bool:
        """
        determines if a DDE link is updated automatically.
        """
    @property
    def IsProtected(self) -> bool:
        """
        If this property is TRUE, the text section is protected and cannot be modified from the user interface.
        """
    @property
    def IsVisible(self) -> bool:
        """
        If this property is FALSE, the text section is hidden.
        """
    @property
    def LinkRegion(self) -> str:
        """
        specifies the source of a file link in the document that is specified in TextSection.FileLink.
        
        The source may be a text section or a bookmark. If TextSection.FileLink is empty, then the current document is searched for the source. If this property is empty and TextSection.FileLink is set, then the complete document content is linked into this section.
        """
    @property
    def SectionLeftMargin(self) -> int:
        """
        determines the left margin of the section
        """
    @property
    def SectionRightMargin(self) -> int:
        """
        determines the left margin of the section
        """
    @property
    def TextColumns(self) -> 'XTextColumns_b17f0bab':
        """
        allows columns to be set into the text section
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.style
from typing_extensions import Literal


class NumberingType(object):
    """
    Const

    These constants are used to specify which numbering style is used.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API NumberingType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style_1_1NumberingType.html>`_
    """
    CHARS_UPPER_LETTER: Literal[0]
    """
    Numbering is put in upper case letters as \"A, B, C, D, ...\".
    """
    CHARS_LOWER_LETTER: Literal[1]
    """
    Numbering is in lower case letters as \"a, b, c, e,...\".
    """
    ROMAN_UPPER: Literal[2]
    """
    Numbering is in Roman numbers with upper case letters as \"I, II, III, IV, ...\".
    """
    ROMAN_LOWER: Literal[3]
    """
    Numbering is in Roman numbers with lower case letters as \"i, ii, iii, iv, ...\".
    """
    ARABIC: Literal[4]
    """
    Numbering is in Arabic numbers as \"1, 2, 3, 4, ...\".
    """
    NUMBER_NONE: Literal[5]
    """
    Numbering is invisible.
    """
    CHAR_SPECIAL: Literal[6]
    """
    Use a character from a specified font.
    """
    PAGE_DESCRIPTOR: Literal[7]
    """
    Numbering is specified in the page style.
    """
    BITMAP: Literal[8]
    """
    Numbering is displayed as a bitmap graphic.
    """
    CHARS_UPPER_LETTER_N: Literal[9]
    """
    Numbering is put in upper case letters as \"A, B, ..., Y, Z, AA, BB, CC, ...
    
    AAA, ...\".
    """
    CHARS_LOWER_LETTER_N: Literal[10]
    """
    Numbering is put in lower case letters as \"a, b, ..., y, z, aa, bb, cc, ...
    
    aaa, ...\".
    """
    TRANSLITERATION: Literal[11]
    """
    A transliteration module will be used to produce numbers in Chinese, Japanese, etc.
    """
    NATIVE_NUMBERING: Literal[12]
    """
    The NativeNumberSupplier service will be called to produce numbers in native languages.
    """
    FULLWIDTH_ARABIC: Literal[13]
    """
    Numbering for fullwidth Arabic number.
    """
    CIRCLE_NUMBER: Literal[14]
    """
    Bullet for Circle Number.
    """
    NUMBER_LOWER_ZH: Literal[15]
    """
    Numbering for Chinese lower case number as \"&#19968;,&#20108;,&#19977;...\".
    """
    NUMBER_UPPER_ZH: Literal[16]
    """
    Numbering for Chinese upper case number.
    """
    NUMBER_UPPER_ZH_TW: Literal[17]
    """
    Numbering for Traditional Chinese upper case number.
    """
    TIAN_GAN_ZH: Literal[18]
    """
    Bullet for Chinese Tian Gan as \"&#30002;,&#20057;,&#19993;...\".
    """
    DI_ZI_ZH: Literal[19]
    """
    Bullet for Chinese Di Zi as \"&#23376;,&#19985;,&#23493;...\".
    """
    NUMBER_TRADITIONAL_JA: Literal[20]
    """
    Numbering for Japanese traditional number.
    """
    AIU_FULLWIDTH_JA: Literal[21]
    """
    Bullet for Japanese AIU fullwidth.
    """
    AIU_HALFWIDTH_JA: Literal[22]
    """
    Bullet for Japanese AIU halfwidth.
    """
    IROHA_FULLWIDTH_JA: Literal[23]
    """
    Bullet for Japanese IROHA fullwidth.
    """
    IROHA_HALFWIDTH_JA: Literal[24]
    """
    Bullet for Japanese IROHA halfwidth.
    """
    NUMBER_UPPER_KO: Literal[25]
    """
    Numbering for Korean upper case number as \"&#22777;,&#36019;,&#21443;...\".
    """
    NUMBER_HANGUL_KO: Literal[26]
    """
    Numbering for Korean Hangul number as \"&#51068;,&#51060;,&#49340;...\".
    """
    HANGUL_JAMO_KO: Literal[27]
    """
    Bullet for Korean Hangul Jamo as \"&#12593;,&#12596;,&#12599;...\".
    """
    HANGUL_SYLLABLE_KO: Literal[28]
    """
    Bullet for Korean Hangul Syllable as \"&#44032;,&#45208;,&#45796;...\".
    """
    HANGUL_CIRCLED_JAMO_KO: Literal[29]
    """
    Bullet for Korean Hangul Circled Jamo as \"&#12896;,&#12897;,&#12898;...\".
    """
    HANGUL_CIRCLED_SYLLABLE_KO: Literal[30]
    """
    Bullet for Korean Hangul Circled Syllable as \"&#12910;,&#12911;,&#12912;...\".
    """
    CHARS_ARABIC: Literal[31]
    """
    Numbering in Arabic alphabet letters as \"&#1571;,&#1576;,&#1578;...\".
    
    **since**
    
        OOo 1.1.2
    """
    CHARS_THAI: Literal[32]
    """
    Numbering in Thai alphabet letters.
    
    **since**
    
        OOo 1.1.2
    """
    CHARS_HEBREW: Literal[33]
    """
    Numbering in Hebrew alphabet letters.
    
    **since**
    
        OOo 2.0
    """
    CHARS_NEPALI: Literal[34]
    """
    Numbering in Nepali alphabet letters.
    
    **since**
    
        OOo 2.0.1
    """
    CHARS_KHMER: Literal[35]
    """
    Numbering in Khmer alphabet letters.
    
    **since**
    
        OOo 2.0.1
    """
    CHARS_LAO: Literal[36]
    """
    Numbering in Lao alphabet letters.
    
    **since**
    
        OOo 2.0.1
    """
    CHARS_TIBETAN: Literal[37]
    """
    Numbering in Tibetan/Dzongkha alphabet letters.
    
    **since**
    
        OOo 2.0.3
    """
    CHARS_CYRILLIC_UPPER_LETTER_BG: Literal[38]
    """
    Numbering in Cyrillic alphabet upper case letters as \"&#1040;, &#1041;,  &#1042;, &#1043;, ..., &#1070;, &#1071;, &#1040;&#1074;, &#1040;&#1072;, &#1040;&#1074;, ... &#1040;&#1072;&#1072;, &#1040;&#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_BG: Literal[39]
    """
    Numbering in Cyrillic alphabet lower case letters as \"&#1072;, &#1073;, &#1074;, &#1075;, ..., &#1102;, &#1103;, &#1072; &#1072;,  &#1072;&#1073;, &#1072;&#1074;, ...  &#1072; &#1072; &#1072;,  &#1072; &#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_UPPER_LETTER_N_BG: Literal[40]
    """
    Numbering in Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1041;&#1073;, &#1042;&#1074;, ... &#1040;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_N_BG: Literal[41]
    """
    Numbering in Cyrillic alphabet upper case letters as \"&#1072;, &#1073;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1073;&#1073;, &#1074;&#1074;, ... &#1072;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_UPPER_LETTER_RU: Literal[42]
    """
    Numbering in Russian Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, &#1042;, &#1043;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1040;&#1073;, &#1040;&#1074;, ... &#1040;&#1072;&#1072;, &#1040;&#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_RU: Literal[43]
    """
    Numbering in Russian Cyrillic alphabet lower case letters as \"&#1072;, &#1073;, &#1074;, &#1075;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1072;&#1073;, &#1072;&#1074;, ... &#1072;&#1072;&#1072;, &#1072;&#1072;&#1073;\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_UPPER_LETTER_N_RU: Literal[44]
    """
    Numbering in Russian Cyrillic alphabet upper case letters as \"&#1040;, &#1041;, ..., &#1070;, &#1071;, &#1040;&#1072;, &#1041;&#1073;, &#1042;&#1074;, ... &#1040;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_CYRILLIC_LOWER_LETTER_N_RU: Literal[45]
    """
    Numbering in Russian Cyrillic alphabet upper case letters as \"&#1072;, &#1073;, ..., &#1102;, &#1103;, &#1072;&#1072;, &#1073;&#1073;, &#1074;&#1074;, ... &#1072;&#1072;&#1072;, ...\".
    
    **since**
    
        OOo 2.0.4
    """
    CHARS_PERSIAN: Literal[46]
    """
    Numbering in Persian alphabet letters (aa, be, pe, te, ...)
    
    **since**
    
        OOo 2.4
    """
    CHARS_MYANMAR: Literal[47]
    """
    Numbering in Myanmar alphabet letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_UPPER_LETTER_SR: Literal[48]
    """
    Numbering in Serbian Cyrillic alphabet upper case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_LOWER_LETTER_SR: Literal[49]
    """
    Numbering in Russian Serbian alphabet lower case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_UPPER_LETTER_N_SR: Literal[50]
    """
    Numbering in Serbian Cyrillic alphabet upper case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_CYRILLIC_LOWER_LETTER_N_SR: Literal[51]
    """
    Numbering in Serbian Cyrillic alphabet upper case letters.
    
    **since**
    
        OOo 3.1
    """
    CHARS_GREEK_UPPER_LETTER: Literal[52]
    """
    Numbering in Greek alphabet upper case letters.
    
    **since**
    
        LibreOffice 3.3
    """
    CHARS_GREEK_LOWER_LETTER: Literal[53]
    """
    Numbering in Greek alphabet lower case letters.
    
    **since**
    
        LibreOffice 3.3
    """
    CHARS_ARABIC_ABJAD: Literal[54]
    """
    Numbering in Arabic alphabet using abjad sequence.
    
    **since**
    
        LibreOffice 3.5
    """
    CHARS_PERSIAN_WORD: Literal[55]
    """
    Numbering in Persian words.
    
    **since**
    
        LibreOffice 3.5
    """
    NUMBER_HEBREW: Literal[56]
    """
    Numbering in Hebrew numerals.
    
    **since**
    
        LibreOffice 5.4
    """
    NUMBER_ARABIC_INDIC: Literal[57]
    """
    Numbering in Arabic-Indic numerals.
    
    **since**
    
        LibreOffice 6.1
    """
    NUMBER_EAST_ARABIC_INDIC: Literal[58]
    """
    Numbering in East Arabic-Indic numerals.
    
    **since**
    
        LibreOffice 6.1
    """
    NUMBER_INDIC_DEVANAGARI: Literal[59]
    """
    Numbering in Indic Devanagari numerals.
    
    **since**
    
        LibreOffice 6.1
    """
    TEXT_NUMBER: Literal[60]
    """
    Numbering in ordinal numbers of the language of the text node for example, 1st, 2nd, 3rd...
    
    in English
    
    **since**
    
        LibreOffice 6.1
    """
    TEXT_CARDINAL: Literal[61]
    """
    Numbering in cardinal numbers of the language of the text node for example, One, Two, Three...
    
    in English
    
    **since**
    
        LibreOffice 6.1
    """
    TEXT_ORDINAL: Literal[62]
    """
    Numbering in ordinal numbers of the language of the text node for example, First, Second, Third...
    
    in English
    
    **since**
    
        LibreOffice 6.1
    """
    SYMBOL_CHICAGO: Literal[63]
    """
    Footnoting symbols according the University of Chicago style: *, &#2020;, &#2021;, &#00a7;, **, &#2020;&#2020; etc.
    
    **since**
    
        LibreOffice 6.4
    """
    ARABIC_ZERO: Literal[64]
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least two, as \"01,
    02, ..., 10, 11, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    ARABIC_ZERO3: Literal[65]
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least three, as \"001, 002, ..., 100, 101, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    ARABIC_ZERO4: Literal[66]
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least four, as \"0001, 0002, ..., 1000, 1001, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    ARABIC_ZERO5: Literal[67]
    """
    Numbering is in Arabic numbers, padded with zero to have a length of at least five, as \"00001, 00002, ..., 10000, 10001, ...\".
    
    **since**
    
        LibreOffice 7.0
    """
    SZEKELY_ROVAS: Literal[68]
    """
    Numbering is in Szekely rovas (Old Hungarian) numerals.
    
    **since**
    
        LibreOffice 7.1
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class ColumnSettings(XPropertySet_bc180bfa):
    """
    Service Class

    describes the common properties of a database column.

    See Also:
        `API ColumnSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1ColumnSettings.html>`_
    """
    @property
    def Align(self) -> int:
        """
        specifies the alignment of columns text.
        
        <p<blockquote>
        
        If the value is VOID , a default alignment should be used according to the datatype of the column.
        """
    @property
    def ControlDefault(self) -> str:
        """
        describes the default value which should be displayed by a control when moving to a new row.
        
        The default is NULL.
        """
    @property
    def ControlModel(self) -> 'XPropertySet_bc180bfa':
        """
        indicates a control model which defines the settings for layouting.
        
        The default is NULL.
        """
    @property
    def FormatKey(self) -> int:
        """
        contains the index of the number format that is used for the column.
        
        The proper value can be determined by using the com.sun.star.util.XNumberFormatter interface.
        
        If the value is VOID , a default number format should be used according to the datatype of the column.
        """
    @property
    def HelpText(self) -> str:
        """
        describes an optional help text which can be used by UI components when representing this column.
        
        The default is NULL.
        """
    @property
    def Hidden(self) -> bool:
        """
        determines whether the column should be displayed or not.
        """
    @property
    def Position(self) -> int:
        """
        Position of the column within a grid.
        
        If the value is VOID , the default position should be taken according.
        """
    @property
    def Width(self) -> int:
        """
        specifies the width of the column displayed in a grid, the unit is 10THMM.
        
        If the value is VOID , a default width should be used according to the label of the column.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .type_description_search_depth import TypeDescriptionSearchDepth as TypeDescriptionSearchDepth_ef6a13a4
    from .x_type_description_enumeration import XTypeDescriptionEnumeration as XTypeDescriptionEnumeration_33e1438
    from ..uno.type_class import TypeClass as TypeClass_853109f2

class XTypeDescriptionEnumerationAccess(XInterface_8f010a43):
    """
    Defines an interface for creating enumerations for type descriptions.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XTypeDescriptionEnumerationAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XTypeDescriptionEnumerationAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XTypeDescriptionEnumerationAccess']

    def createTypeDescriptionEnumeration(self, moduleName: str, types: 'typing.Tuple[TypeClass_853109f2, ...]', depth: 'TypeDescriptionSearchDepth_ef6a13a4') -> 'XTypeDescriptionEnumeration_33e1438':
        """
        Creates an enumeration for type descriptions.
        
        An enumeration is always created for a UNOIDL module. The enumeration contents can be restricted by specifying type classes. Only types that match one of the supplied type classes will be part of the collection. Additionally, it is possible to specify the depth for the search within the underlying type description tree.
        
        Valid types classes are:
        
        The enumeration returns implementations of XTypeDescription. Following concrete UNOIDL parts represented by specialized interfaces derived from XTypeDescription can be returned by the enumerator:

        Raises:
            NoSuchTypeNameException: ``NoSuchTypeNameException``
            InvalidTypeNameException: ``InvalidTypeNameException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
from .post_command_argument import PostCommandArgument as PostCommandArgument_fc590dea
from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class PostCommandArgument2(PostCommandArgument_fc590dea):
    """
    Struct Class

    The argument for the command \"post\".

    See Also:
        `API PostCommandArgument2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1PostCommandArgument2.html>`_
    """
    typeName: Literal['com.sun.star.ucb.PostCommandArgument2']

    def __init__(self, Source: typing.Optional[XInputStream_98d40ab4] = ..., Sink: typing.Optional[XInterface_8f010a43] = ..., MediaType: typing.Optional[str] = ..., Referer: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInputStream, optional): Source value.
            Sink (XInterface, optional): Sink value.
            MediaType (str, optional): MediaType value.
            Referer (str, optional): Referer value.
        """


    @property
    def MediaType(self) -> str:
        """
        The media type (mime type) for the data to post.
        """


    @property
    def Referer(self) -> str:
        """
        The URL of the referrer.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb.application
from typing_extensions import Literal
from ..command_type import CommandType


class DatabaseObject(object):
    """
    Const

    denotes different objects within a database document
    
    **since**
    
        OOo 2.2

    See Also:
        `API DatabaseObject <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1DatabaseObject.html>`_
    """
    TABLE: Literal[0]
    """
    denotes a table in a database
    
    Note that table here is a more general term. In OpenOffice.org Base, views are also represented as tables, since to the user, the behave pretty much as tables do.
    """
    QUERY: Literal[1]
    """
    denotes a query in a database document
    """
    FORM: Literal[2]
    """
    denotes a form in a database document
    """
    REPORT: Literal[3]
    """
    denotes a report in a database document
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .proofreading_result import ProofreadingResult as ProofreadingResult_6cc910d4
    from ..text.x_flat_paragraph import XFlatParagraph as XFlatParagraph_c8310c42
    from ..text.x_flat_paragraph_iterator_provider import XFlatParagraphIteratorProvider as XFlatParagraphIteratorProvider_c37e12d7

class XProofreadingIterator(XInterface_8f010a43):
    """
    API for the proofreading iterator that mediates between the document and the proofreader.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API XProofreadingIterator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XProofreadingIterator.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.linguistic2.XProofreadingIterator']

    def checkSentenceAtPosition(self, xDocument: 'XInterface_8f010a43', xFlatParagraph: 'XFlatParagraph_c8310c42', aText: str, aLocale: 'Locale_70d308fa', nStartOfSentencePosition: int, nSuggestedBehindEndOfSentencePosition: int, nErrorPositionInParagraph: int) -> 'ProofreadingResult_6cc910d4':
        """
        start proofreading from a given position

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isProofreading(self, xDocument: 'XInterface_8f010a43') -> bool:
        """
        checks if the given document is currently being checked
        """
    def resetIgnoreRules(self) -> None:
        """
        clears the list of ignored rules for each proofreader
        """
    def startProofreading(self, xDocument: 'XInterface_8f010a43', xIteratorProvider: 'XFlatParagraphIteratorProvider_c37e12d7') -> None:
        """
        start proofreading and automatically process the whole text

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.dom
from typing_extensions import Literal
import typing
from .x_node import XNode as XNode_83fb09a5
if typing.TYPE_CHECKING:
    from .x_attr import XAttr as XAttr_840309ba
    from .xcdata_section import XCDATASection as XCDATASection_d9c00c51
    from .x_comment import XComment as XComment_a3690af2
    from .xdom_implementation import XDOMImplementation as XDOMImplementation_22320ec5
    from .x_document_fragment import XDocumentFragment as XDocumentFragment_17850e92
    from .x_document_type import XDocumentType as XDocumentType_e0340d00
    from .x_element import XElement as XElement_a33d0ae9
    from .x_entity_reference import XEntityReference as XEntityReference_9b70e2b
    from .x_node_list import XNodeList as XNodeList_ae540b41
    from .x_processing_instruction import XProcessingInstruction as XProcessingInstruction_691810de
    from .x_text import XText as XText_842c09c4

class XDocument(XNode_83fb09a5):
    """

    See Also:
        `API XDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDocument.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.dom.XDocument']

    def createAttribute(self, name: str) -> 'XAttr_840309ba':
        """
        Creates an Attr of the given name.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified name contains an illegal character.

        Raises:
            DOMException: ``DOMException``
        """
    def createAttributeNS(self, namespaceURI: str, qualifiedName: str) -> 'XAttr_840309ba':
        """
        Creates an attribute of the given qualified name and namespace URI.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified qualified name contains an illegal character, per the XML 1.0 specification . NAMESPACE_ERR: Raised if the qualifiedName is malformed per the Namespaces in XML specification, if the qualifiedName has a prefix and the namespaceURI is null, if the qualifiedName has a prefix that is \"xml\" and the namespaceURI is different from \" http://www.w3.org/XML/1998/namespace\", or if the qualifiedName, or its prefix, is \"xmlns\" and the namespaceURI is different from \" http://www.w3.org/2000/xmlns/\". NOT_SUPPORTED_ERR: Always thrown if the current document does not support the \"XML\" feature, since namespaces were defined by XML.

        Raises:
            DOMException: ``DOMException``
        """
    def createCDATASection(self, data: str) -> 'XCDATASection_d9c00c51':
        """
        Creates a CDATASection node whose value is the specified string.
        
        Throws: DOMException - NOT_SUPPORTED_ERR: Raised if this document is an HTML document.

        Raises:
            DOMException: ``DOMException``
        """
    def createComment(self, data: str) -> 'XComment_a3690af2':
        """
        Creates a Comment node given the specified string.
        """
    def createDocumentFragment(self) -> 'XDocumentFragment_17850e92':
        """
        Creates an empty DocumentFragment object.
        """
    def createElement(self, tagName: str) -> 'XElement_a33d0ae9':
        """
        Creates an element of the type specified.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified name contains an illegal character.

        Raises:
            DOMException: ``DOMException``
        """
    def createElementNS(self, namespaceURI: str, qualifiedName: str) -> 'XElement_a33d0ae9':
        """
        Creates an element of the given qualified name and namespace URI.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified qualified name contains an illegal character, per the XML 1.0 specification . NAMESPACE_ERR: Raised if the qualifiedName is malformed per the Namespaces in XML specification, if the qualifiedName has a prefix and the namespaceURI is null, or if the qualifiedName has a prefix that is \"xml\" and the namespaceURI is different from \" http://www.w3.org/XML/1998/namespace\" . NOT_SUPPORTED_ERR: Always thrown if the current document does not support the \"XML\" feature, since namespaces were defined by XML.

        Raises:
            DOMException: ``DOMException``
        """
    def createEntityReference(self, name: str) -> 'XEntityReference_9b70e2b':
        """
        Throws: DOMException - NOT_SUPPORTED_ERR: Raised if the type of node being imported is not supported.
        
        Creates an EntityReference object. Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified name contains an illegal character. NOT_SUPPORTED_ERR: Raised if this document is an HTML document.

        Raises:
            DOMException: ``DOMException``
        """
    def createProcessingInstruction(self, target: str, data: str) -> 'XProcessingInstruction_691810de':
        """
        Creates a ProcessingInstruction node given the specified name and data strings.
        
        Throws: DOMException - INVALID_CHARACTER_ERR: Raised if the specified target contains an illegal character. NOT_SUPPORTED_ERR: Raised if this document is an HTML document.

        Raises:
            DOMException: ``DOMException``
        """
    def createTextNode(self, data: str) -> 'XText_842c09c4':
        """
        Creates a Text node given the specified string.
        """
    def getDoctype(self) -> 'XDocumentType_e0340d00':
        """
        The Document Type Declaration (see DocumentType) associated with this document.
        """
    def getDocumentElement(self) -> 'XElement_a33d0ae9':
        """
        This is a convenience attribute that allows direct access to the child node that is the root element of the document.
        """
    def getElementById(self, elementId: str) -> 'XElement_a33d0ae9':
        """
        Returns the Element whose ID is given by elementId.
        """
    def getElementsByTagName(self, tagname: str) -> 'XNodeList_ae540b41':
        """
        Returns a NodeList of all the Elements with a given tag name in the order in which they are encountered in a preorder traversal of the Document tree.
        """
    def getElementsByTagNameNS(self, namespaceURI: str, localName: str) -> 'XNodeList_ae540b41':
        """
        Returns a NodeList of all the Elements with a given local name and namespace URI in the order in which they are encountered in a preorder traversal of the Document tree.
        """
    def getImplementation(self) -> 'XDOMImplementation_22320ec5':
        """
        The DOMImplementation object that handles this document.
        """
    def importNode(self, importedNode: 'XNode_83fb09a5', deep: bool) -> 'XNode_83fb09a5':
        """
        Imports a node from another document to this document.
        
        Throws: DOMException - NOT_SUPPORTED_ERR: Raised if the type of node being imported is not supported.

        Raises:
            DOMException: ``DOMException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class DateDisplayFormat(object):
    """
    Const

    This constants define how a date field is formatted before it is displayed.
    
    The format may also depend on the system or document locale. The samples are in German.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DateDisplayFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html>`_
    """
    STANDARD_SHORT: Literal[0]
    """
    the shortest system standard
    """
    STANDARD_LONG: Literal[1]
    """
    the longest system standard
    """
    MMDDYY: Literal[2]
    """
    22.11.73
    """
    MMDDYYYY: Literal[3]
    """
    22.11.1973
    """
    DDMMMYYYY: Literal[4]
    DDMMMMYYYY: Literal[5]
    NNDDMMMMYYYY: Literal[6]
    """
    Do, 22.
    
    November 1973
    """
    NNNNDDMMMMYYYY: Literal[7]
    """
    Donnerstag, 22.
    
    November 1973
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.smarttags
from typing_extensions import Literal
import typing
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
if typing.TYPE_CHECKING:
    from ..container.x_string_key_map import XStringKeyMap as XStringKeyMap_ffc60de1
    from ..frame.x_controller import XController as XController_b00e0b8f
    from ..lang.locale import Locale as Locale_70d308fa
    from ..text.x_text_range import XTextRange as XTextRange_9a910ab7

class XSmartTagAction(XInitialization_d46c0cca):
    """
    provides access to smart tag actions.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XSmartTagAction <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1smarttags_1_1XSmartTagAction.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.smarttags.XSmartTagAction']

    def getActionCaptionFromID(self, nActionID: int, aApplicationName: str, aLocale: 'Locale_70d308fa', xProperties: 'XStringKeyMap_ffc60de1', aText: str, aXML: str, xController: 'XController_b00e0b8f', xTarget: 'XTextRange_9a910ab7') -> str:
        """
        obtains a caption for a specified action for use in user interfaces.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getActionCount(self, aSmartTagName: str, xController: 'XController_b00e0b8f', xProperties: 'XStringKeyMap_ffc60de1') -> int:
        """
        obtains the number of actions provided for a specified smart tag type.
        """
    def getActionID(self, aSmartTagName: str, nActionIndex: int, xController: 'XController_b00e0b8f') -> int:
        """
        obtains a unique integer identifier for an action.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getActionNameFromID(self, nActionID: int, xController: 'XController_b00e0b8f') -> str:
        """
        obtains a language independent name of an action.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getDescription(self, aLocale: 'Locale_70d308fa') -> str:
        """
        obtains a detailed description of this action component.
        """
    def getName(self, aLocale: 'Locale_70d308fa') -> str:
        """
        obtains a name that describes this action component.
        """
    def getSmartTagCaption(self, nSmartTagIndex: int, aLocale: 'Locale_70d308fa') -> str:
        """
        obtains the caption of the smart tag type for using in user interfaces.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getSmartTagName(self, nSmartTagIndex: int) -> str:
        """
        obtains the name of one specific smart tag type supported by this action component.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def invokeAction(self, nActionID: int, aApplicationName: str, xController: 'XController_b00e0b8f', xTarget: 'XTextRange_9a910ab7', xProperties: 'XStringKeyMap_ffc60de1', aText: str, aXML: str, aLocale: 'Locale_70d308fa') -> None:
        """
        invokes an action.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isCaptionDynamic(self, nActionID: int, aApplicationName: str, xController: 'XController_b00e0b8f', aLocale: 'Locale_70d308fa') -> bool:
        """
        determines whether a caption is dynamic.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isShowSmartTagIndicator(self, nActionID: int, aApplicationName: str, xController: 'XController_b00e0b8f', aLocale: 'Locale_70d308fa') -> bool:
        """
        determines whether the smart tag indicator should be visible.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @property
    def SmartTagCount(self) -> int:
        """
        the number of smart tag types supported by this action component.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ActionEvent(EventObject_a3d70b03):
    """
    Struct Class

    a semantic event which indicates that a component-defined action occurred.
    
    This high-level event is generated by a component (such as a Button) when the component-specific action occurs (such as being pressed). The event is passed to every XActionListener object that registered to receive such events using the component's addActionListener method.
    
    The object that implements the XActionListener interface gets this ActionEvent when the event occurs. The listener is therefore spared the details of processing individual mouse movements and mouse clicks, and can instead process a \"meaningful\" (semantic) event like \"button pressed\".

    See Also:
        `API ActionEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1ActionEvent.html>`_
    """
    typeName: Literal['com.sun.star.awt.ActionEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., ActionCommand: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            ActionCommand (str, optional): ActionCommand value.
        """


    @property
    def ActionCommand(self) -> str:
        """
        contains the command string associated with this action.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2.data
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .label_origin import LabelOrigin as LabelOrigin_f66b0d5c

class XDataSequence(XInterface_8f010a43):
    """
    allows access to a one-dimensional sequence of data.
    
    The data that is stored in this container may contain different types.

    See Also:
        `API XDataSequence <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataSequence.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.data.XDataSequence']

    def generateLabel(self, eLabelOrigin: 'LabelOrigin_f66b0d5c') -> 'typing.Tuple[str, ...]':
        """
        creates a label that describes the origin of this data sequence.
        
        This is useful, if a XLabeledDataSequence has no label sequence. In this case you can call this method at the value sequence to obtain a fitting replacement label.
        
        The sequence returned here may be empty if no suitable label can be generated.
        
        The strings returned should be localized.
        
        If you have a non quadratic range you can ask for labels for the longer side with parameter LONG_SIDE or you can obtain labels for the shorter side with parameter SHORT_SIDE.
        
        If the range is not structured in a tabular way you may receive no label.
        
        Example: Assuming this sequence has a Range representation spanning row 5 and 6 in column 8. Following sequences of strings or similar strings are expected as return values:
        
        generateLabel( SHORT_SIDE ) -> \"Column 8\" generateLabel( LONG_SIDE ) -> \"Row 5\" \"Row 6\" generateLabel( COLUMN ) -> \"Column 8\" generateLabel( ROW ) -> \"Row 5\" \"Row 6\"
        
        Which strings exactly you return depends on the naming scheme of the application which provides its tabular data.
        """
    def getData(self) -> 'typing.Tuple[object, ...]':
        """
        retrieves the data stored in this component.
        """
    def getNumberFormatKeyByIndex(self, nIndex: int) -> int:
        """
        returns a number format key for the value at the given index in the data sequence.
        
        If nIndex is -1, a key for the entire sequence should be returned, e.g. the most commonly used one.
        
        If number formats are not supported, or there is no heuristic to return a key for the entire series, return 0 here.
        
        The number format key must be valid for the com.sun.star.util.XNumberFormatsSupplier given by the XDataProvider, or 0 which is assumed to be always valid.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getSourceRangeRepresentation(self) -> str:
        """
        returns the (UI) range representation string used by this XDataSequence.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.configuration.access_root_element import AccessRootElement as AccessRootElement
from .._pyi.configuration.administration_provider import AdministrationProvider as AdministrationProvider
from .._pyi.configuration.cannot_load_configuration_exception import CannotLoadConfigurationException as CannotLoadConfigurationException
from .._pyi.configuration.configuration_access import ConfigurationAccess as ConfigurationAccess
from .._pyi.configuration.configuration_provider import ConfigurationProvider as ConfigurationProvider
from .._pyi.configuration.configuration_registry import ConfigurationRegistry as ConfigurationRegistry
from .._pyi.configuration.configuration_update_access import ConfigurationUpdateAccess as ConfigurationUpdateAccess
from .._pyi.configuration.corrupted_configuration_exception import CorruptedConfigurationException as CorruptedConfigurationException
from .._pyi.configuration.corrupted_ui_configuration_exception import CorruptedUIConfigurationException as CorruptedUIConfigurationException
from .._pyi.configuration.default_provider import DefaultProvider as DefaultProvider
from .._pyi.configuration.group_access import GroupAccess as GroupAccess
from .._pyi.configuration.group_element import GroupElement as GroupElement
from .._pyi.configuration.group_update import GroupUpdate as GroupUpdate
from .._pyi.configuration.hierarchy_access import HierarchyAccess as HierarchyAccess
from .._pyi.configuration.hierarchy_element import HierarchyElement as HierarchyElement
from .._pyi.configuration.installation_incomplete_exception import InstallationIncompleteException as InstallationIncompleteException
from .._pyi.configuration.invalid_bootstrap_file_exception import InvalidBootstrapFileException as InvalidBootstrapFileException
from .._pyi.configuration.missing_bootstrap_file_exception import MissingBootstrapFileException as MissingBootstrapFileException
from .._pyi.configuration.property_hierarchy import PropertyHierarchy as PropertyHierarchy
from .._pyi.configuration.read_only_access import ReadOnlyAccess as ReadOnlyAccess
from .._pyi.configuration.read_write_access import ReadWriteAccess as ReadWriteAccess
from .._pyi.configuration.set_access import SetAccess as SetAccess
from .._pyi.configuration.set_element import SetElement as SetElement
from .._pyi.configuration.set_update import SetUpdate as SetUpdate
from .._pyi.configuration.simple_set_access import SimpleSetAccess as SimpleSetAccess
from .._pyi.configuration.simple_set_update import SimpleSetUpdate as SimpleSetUpdate
from .._pyi.configuration.update import Update as Update
from .._pyi.configuration.update_root_element import UpdateRootElement as UpdateRootElement
from .._pyi.configuration.x_read_write_access import XReadWriteAccess as XReadWriteAccess
from .._pyi.configuration.x_template_container import XTemplateContainer as XTemplateContainer
from .._pyi.configuration.x_template_instance import XTemplateInstance as XTemplateInstance
from .._pyi.configuration.x_update import XUpdate as XUpdate
from .._pyi.configuration.the_default_provider import theDefaultProvider as theDefaultProvider



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
import typing
from .x_repository import XRepository as XRepository_995d0adc
if typing.TYPE_CHECKING:
    from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa
    from .x_metadatable import XMetadatable as XMetadatable_a3000af0
    from .x_node import XNode as XNode_5ee40822
    from .x_resource import XResource as XResource_842709e4
    from .xuri import XURI as XURI_5682078c

class XDocumentRepository(XRepository_995d0adc):
    """
    extends XRepository with document-specific functionality.
    
    This subclass of XRepository provides some methods which only make sense for repositories that are attached to a document. For example, the methods allow for manipulating in-content metadata, which is stored as RDFa.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XDocumentRepository <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XDocumentRepository.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rdf.XDocumentRepository']

    def getStatementRDFa(self, Element: 'XMetadatable_a3000af0') -> object:
        """
        find the RDFa statement(s) associated with an ODF element.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            RepositoryException: ``RepositoryException``
        """
    def getStatementsRDFa(self, Subject: 'XResource_842709e4', Predicate: 'XURI_5682078c', Object: 'XNode_5ee40822') -> 'XEnumeration_f2180daa':
        """
        gets matching RDFa statements from the repository.
        
        This method exists because RDFa statements are not part of any named graph, and thus they cannot be enumerated with XNamedGraph.getStatements().
        
        Any parameter may be NULL, which acts as a wildcard. For example, to get all statements about myURI: getStatementsRDFa(myURI, null, null)

        Raises:
            RepositoryException: ``RepositoryException``
        """
    def removeStatementRDFa(self, Element: 'XMetadatable_a3000af0') -> None:
        """
        remove the RDFa statement(s) that correspond to an ODF element from the repository.
        
        RDFa statements are handled specially because they are not logically part of any graph.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            RepositoryException: ``RepositoryException``
        """
    def setStatementRDFa(self, Subject: 'XResource_842709e4', Predicates: 'typing.Tuple[XURI_5682078c, ...]', Object: 'XMetadatable_a3000af0', RDFaContent: str, RDFaDatatype: 'XURI_5682078c') -> None:
        """
        update the RDFa statement(s) that correspond to an ODF element in the repository.
        
        This method will do the following steps:
        
        RDFa statements are handled specially because they are not logically part of any named graph in the repository. Also, they have rather unusual semantics; just using XNamedGraph.addStatement() would be ambiguous: if the object is a XMetadatable, do we insert the object itself (URI) or its literal content (RDFa)?

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            RepositoryException: ``RepositoryException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..container.x_named import XNamed as XNamed_a6520b08
if typing.TYPE_CHECKING:
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56

class XNamedRange(XNamed_a6520b08):
    """
    provides access to the settings of a named range in a spreadsheet document.

    See Also:
        `API XNamedRange <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRange.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XNamedRange']

    def getContent(self) -> str:
        """
        returns the content of the named range.
        
        The content can be a reference to a cell or cell range or any formula expression.
        """
    def getReferencePosition(self) -> 'CellAddress_ae5f0b56':
        """
        returns the position in the document which is used as a base for relative references in the content.
        """
    def getType(self) -> int:
        """
        returns the type of the named range.
        
        This is a combination of flags as defined in NamedRangeFlag.
        """
    def setContent(self, aContent: str) -> None:
        """
        sets the content of the named range.
        
        The content can be a reference to a cell or cell range or any formula expression.
        """
    def setReferencePosition(self, aReferencePosition: 'CellAddress_ae5f0b56') -> None:
        """
        sets the position in the document which is used as a base for relative references in the content.
        """
    def setType(self, nType: int) -> None:
        """
        sets the type of the named range.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from .x_accessible_text import XAccessibleText as XAccessibleText_5b77105b
if typing.TYPE_CHECKING:
    from .text_segment import TextSegment as TextSegment_1e5b0ee8

class XAccessibleMultiLineText(XAccessibleText_5b77105b):
    """
    Implement this interface to give provide a mapping between text index and line numbers.
    
    This interface is typically used in conjunction with the XAccessibleText interface and extents it with a notion of line numbers
    
    **since**
    
        OOo 3.0 not yet published

    See Also:
        `API XAccessibleMultiLineText <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleMultiLineText.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleMultiLineText']

    def getLineNumberAtIndex(self, nIndex: int) -> int:
        """
        Returns the line number at the specified index.
        
        For a text object that is spread over multiple lines, this method provides a mapping from a text index to the corresponding line number.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getNumberOfLineWithCaret(self) -> int:
        """
        Returns the number of the line in which the caret is located.
        
        The line number returned will most of the time be identical to calling XAccessibleMultiLineText.getLineNumberAtIndex() with the index returned by XAccessibleText.getCaretPosition() beside the following special case:
        
        Some text implementations place the caret at the end of the current line when the End key gets pressed. Since the index of this position is identical to the one of the first character of the following line, XAccessibleMultiLineText.getLineNumberAtIndex() will return the line following the current one in this case.
        """
    def getTextAtLineNumber(self, nLineNo: int) -> 'TextSegment_1e5b0ee8':
        """
        Returns the text of the specified line.
        
        Returns the substring of text that makes up the specified line number.
        
        The number of lines can be obtained by calling XAccessibleMultiLineText.getLineNumberAtIndex() with the index of the last character. In a loop, the last line has been reached when TextSegment.SegmentEnd of the returned value is equal to the index of the last character of the text.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getTextAtLineWithCaret(self) -> 'TextSegment_1e5b0ee8':
        """
        Returns the text of the line in which the caret is located.
        
        The substring returned will most of the time be identical to calling XAccessibleText.getTextAtIndex() with the index returned by XAccessibleText.getCaretPosition() and type AccessibleTextType.LINE beside the following special case:
        
        Some text implementations place the caret at the end of the current line when the End key gets pressed. Since the index of this position is identical to the one of the first character of the following line, XAccessibleMultiLineText.getLineNumberAtIndex() will return the line following the current one in this case.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.table
from typing_extensions import Literal
import typing
from ..beans.x_fast_property_set import XFastPropertySet as XFastPropertySet_ee6b0d88
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_cell_range import XCellRange as XCellRange_a2f70ad5
from .x_column_row_range import XColumnRowRange as XColumnRowRange_e0e70cfb
from ..util.x_modifiable import XModifiable as XModifiable_a4f60b0a
if typing.TYPE_CHECKING:
    from .x_cell_cursor import XCellCursor as XCellCursor_ae900b66

class XTable(XFastPropertySet_ee6b0d88, XPropertySet_bc180bfa, XComponent_98dc0ab5, XCellRange_a2f70ad5, XColumnRowRange_e0e70cfb, XModifiable_a4f60b0a):
    """

    See Also:
        `API XTable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XTable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.table.XTable']

    def createCursor(self) -> 'XCellCursor_ae900b66':
        """
        creates a cell cursor including the whole table
        """
    def createCursorByRange(self, Range: 'XCellRange_a2f70ad5') -> 'XCellCursor_ae900b66':
        """
        creates a cell cursor to travel in the given range context.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @property
    def ColumnCount(self) -> int:
        """
        stores the current column count of this table
        """

    @property
    def RowCount(self) -> int:
        """
        stores the current row count of this table
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.reflection
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .param_mode import ParamMode as ParamMode_d7260ca9
from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a


class ParamInfo(object):
    """
    Struct Class

    Provides information about a formal parameter of a method.

    See Also:
        `API ParamInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1reflection_1_1ParamInfo.html>`_
    """
    typeName: Literal['com.sun.star.reflection.ParamInfo']

    def __init__(self, aName: typing.Optional[str] = ..., aMode: typing.Optional[ParamMode_d7260ca9] = ..., aType: typing.Optional[XIdlClass_d63a0c9a] = ...) -> None:
        """
        Constructor

        Arguments:
            aName (str, optional): aName value.
            aMode (ParamMode, optional): aMode value.
            aType (XIdlClass, optional): aType value.
        """


    @property
    def aName(self) -> str:
        """
        name of the parameter
        """


    @property
    def aMode(self) -> ParamMode_d7260ca9:
        """
        parameter mode: in, out, inout
        """


    @property
    def aType(self) -> XIdlClass_d63a0c9a:
        """
        formal type of the parameter
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.deployment
from typing_extensions import Literal
from abc import ABC

class XPackageTypeInfo(ABC):
    """
    Objects of this interface provide information about a package's type.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPackageTypeInfo <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageTypeInfo.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.deployment.XPackageTypeInfo']

    def getDescription(self) -> str:
        """
        returns a description string to describe a package type.

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """
    def getFileFilter(self) -> str:
        """
        returns a file filter string for the file picker user interface.
        
        Both, the short description string and file filter string will be passed to com.sun.star.ui.dialogs.XFilterManager.appendFilter().
        """
    def getIcon(self, highContrast: bool, smallIcon: bool) -> object:
        """
        returns an icon for a package.
        """
    def getMediaType(self) -> str:
        """
        returns the media type of a package, e.g.
        
        application/vnd.sun.star.basic-script.
        """
    def getShortDescription(self) -> str:
        """
        returns a short description string to describe a package type (one line only).

        Raises:
            ExtensionRemovedException: ``ExtensionRemovedException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .database_registration_event import DatabaseRegistrationEvent as DatabaseRegistrationEvent_56721053

class XDatabaseRegistrationsListener(XEventListener_c7230c4a):
    """
    implemented by components which want to be notified of changes in the application-wide registered databases.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XDatabaseRegistrationsListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseRegistrationsListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XDatabaseRegistrationsListener']

    def changedDatabaseLocation(self, Event: 'DatabaseRegistrationEvent_56721053') -> None:
        """
        called when the location of a registered database changed
        
        Note that this talks about registration data only. That is, if the actual file denoted by the database registration is moved, this is in no way monitored or reported. Only (successful) calls to XDatabaseRegistrations.changeDatabaseLocation() are reported here.
        """
    def registeredDatabaseLocation(self, Event: 'DatabaseRegistrationEvent_56721053') -> None:
        """
        called when a database has been registered
        """
    def revokedDatabaseLocation(self, Event: 'DatabaseRegistrationEvent_56721053') -> None:
        """
        called when a database registration has been revoked
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class LocaleDataItem(object):
    """
    Struct Class

    Locale specific data, for example, separators, quotation marks.

    See Also:
        `API LocaleDataItem <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LocaleDataItem.html>`_
    """
    typeName: Literal['com.sun.star.i18n.LocaleDataItem']

    def __init__(self, unoID: typing.Optional[str] = ..., dateSeparator: typing.Optional[str] = ..., thousandSeparator: typing.Optional[str] = ..., decimalSeparator: typing.Optional[str] = ..., timeSeparator: typing.Optional[str] = ..., time100SecSeparator: typing.Optional[str] = ..., listSeparator: typing.Optional[str] = ..., quotationStart: typing.Optional[str] = ..., quotationEnd: typing.Optional[str] = ..., doubleQuotationStart: typing.Optional[str] = ..., doubleQuotationEnd: typing.Optional[str] = ..., timeAM: typing.Optional[str] = ..., timePM: typing.Optional[str] = ..., measurementSystem: typing.Optional[str] = ..., LongDateDayOfWeekSeparator: typing.Optional[str] = ..., LongDateDaySeparator: typing.Optional[str] = ..., LongDateMonthSeparator: typing.Optional[str] = ..., LongDateYearSeparator: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            unoID (str, optional): unoID value.
            dateSeparator (str, optional): dateSeparator value.
            thousandSeparator (str, optional): thousandSeparator value.
            decimalSeparator (str, optional): decimalSeparator value.
            timeSeparator (str, optional): timeSeparator value.
            time100SecSeparator (str, optional): time100SecSeparator value.
            listSeparator (str, optional): listSeparator value.
            quotationStart (str, optional): quotationStart value.
            quotationEnd (str, optional): quotationEnd value.
            doubleQuotationStart (str, optional): doubleQuotationStart value.
            doubleQuotationEnd (str, optional): doubleQuotationEnd value.
            timeAM (str, optional): timeAM value.
            timePM (str, optional): timePM value.
            measurementSystem (str, optional): measurementSystem value.
            LongDateDayOfWeekSeparator (str, optional): LongDateDayOfWeekSeparator value.
            LongDateDaySeparator (str, optional): LongDateDaySeparator value.
            LongDateMonthSeparator (str, optional): LongDateMonthSeparator value.
            LongDateYearSeparator (str, optional): LongDateYearSeparator value.
        """


    @property
    def unoID(self) -> str:
        """
        internal ID string, not unique, not meaningful to the outer world
        """


    @property
    def dateSeparator(self) -> str:
        """
        date separator, for example, \"/\" or \".\" or \"-\"
        """


    @property
    def thousandSeparator(self) -> str:
        """
        group and thousand separator, for example, \",\" or \".\"
        """


    @property
    def decimalSeparator(self) -> str:
        """
        decimal separator, for example, \".\" or \",\"
        """


    @property
    def timeSeparator(self) -> str:
        """
        time separator, for example, \":\"
        """


    @property
    def time100SecSeparator(self) -> str:
        """
        time 100th seconds separator, for example, \",\"
        """


    @property
    def listSeparator(self) -> str:
        """
        list separator, for example, \";\"
        """


    @property
    def quotationStart(self) -> str:
        """
        single quotation mark start
        """


    @property
    def quotationEnd(self) -> str:
        """
        single quotation mark end
        """


    @property
    def doubleQuotationStart(self) -> str:
        """
        double quotation mark start
        """


    @property
    def doubleQuotationEnd(self) -> str:
        """
        double quotation mark end
        """


    @property
    def timeAM(self) -> str:
        """
        time AM symbol, for example, \"AM\" or \"am\"
        """


    @property
    def timePM(self) -> str:
        """
        time PM symbol, for example, \"PM\" or \"pm\"
        """


    @property
    def measurementSystem(self) -> str:
        """
        measurement system, \"metric\" or \"us\"
        """


    @property
    def LongDateDayOfWeekSeparator(self) -> str:
        """
        long date day of week separator, for example, \", \"
        """


    @property
    def LongDateDaySeparator(self) -> str:
        """
        long date day separator, for example, \", \"
        """


    @property
    def LongDateMonthSeparator(self) -> str:
        """
        long date month separator, for example, \" \"
        """


    @property
    def LongDateYearSeparator(self) -> str:
        """
        long date year separator, for example, \" \"
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Constants to identify the character type.

Returned by XCharacterClassification.getCharacterType() and XCharacterClassification.getStringType()

See Also:
    `API KCharacterType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1KCharacterType.html>`_
"""
DIGIT: Literal[1]
"""
digit
"""
UPPER: Literal[2]
"""
upper case alpha letter
"""
LOWER: Literal[4]
"""
lower case alpha letter
"""
TITLE_CASE: Literal[8]
"""
title case alpha letter
"""
ALPHA: Literal[14]
"""
any alpha, ALPHA = UPPER | LOWER | TITLE_CASE
"""
CONTROL: Literal[16]
"""
control character
"""
PRINTABLE: Literal[32]
"""
printable character
"""
BASE_FORM: Literal[64]
"""
base form
"""
LETTER: Literal[128]
"""
any UnicodeType...._LETTER.

Note that a LETTER must not necessarily be ALPHA
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xsd
from .x_data_type import XDataType as XDataType_83f209cb

class Decimal(XDataType_83f209cb):
    """
    Service Class

    specifies an XSD compliant decimal type

    See Also:
        `API Decimal <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xsd_1_1Decimal.html>`_
    """
    @property
    def FractionDigits(self) -> int:
        """
        fractionDigits is the maximum number of digits in the fractional part of values of decimal data
        
        The value of fractionDigits must be a non negative integer.
        
        See http://www.w3.org/TR/xmlschema-2/#rf-fractionDigits
        """
    @property
    def MaxExclusiveDouble(self) -> float:
        """
        specifies the exclusive upper bound for the value
        """
    @property
    def MaxInclusiveDouble(self) -> float:
        """
        specifies the inclusive upper bound for the value
        """
    @property
    def MinExclusiveDouble(self) -> float:
        """
        specifies the exclusive lower bound for the value
        """
    @property
    def MinInclusiveDouble(self) -> float:
        """
        specifies the inclusive lower bound for the value
        """
    @property
    def TotalDigits(self) -> int:
        """
        totalDigits is the maximum number of digits in values of decimal data types.
        
        The value of totalDigits must be a positive integer.
        
        See http://www.w3.org/TR/xmlschema-2/#rf-totalDigits
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XImporter(XInterface_8f010a43):
    """
    makes it possible to connect a document with an ImportFilter
    
    An ImportFilter must know the target of his filter operation. To set this on a filter is part of this interface. Same mechanism exist for export too.

    See Also:
        `API XImporter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XImporter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XImporter']

    def setTargetDocument(self, Document: 'XComponent_98dc0ab5') -> None:
        """
        sets the target document for the importer

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from ..geometry.real_rectangle2_d import RealRectangle2D as RealRectangle2D_d9b0e03
    from .caret import Caret as Caret_9b480ab5
    from .string_context import StringContext as StringContext_d50e22
    from .text_hit import TextHit as TextHit_b25d0b90
    from .x_canvas_font import XCanvasFont as XCanvasFont_e3380d11
    from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20

class XTextLayout(XInterface_8f010a43):
    """
    This is the central interface for text layouting.
    
    This is the central interface for text-related tasks more complicated than simple string rendering. Note that all query methods are subject to the current layout state of this object. That is, calls to XTextLayout.justify() or XTextLayout.applyLogicalAdvancements() are likely to change subsequent output of those query methods.
    
    Similar to XCanvasFont, all measurements and coordinates accepted and returned by this interface are relative to the font's local coordinate system (which only equals device coordinate space, if the combined render transformation used during text output is the identity transformation). Conversely, if the combined transformation used during text output is not the identity transformation, all measurements returned by this interface should be subjected to that transformation, to yield values in device coordinate space. Depending on the underlying font technology, actual device output might be off by up to one device pixel from the transformed metrics.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XTextLayout <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XTextLayout.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XTextLayout']

    def applyLogicalAdvancements(self, aAdvancements: 'typing.Tuple[float, ...]') -> None:
        """
        Apply explicit advancements for every character in the layout string.
        
        This method applies the specified advancements to every logical character in the input string (not for every glyph. There might be multiple glyphs per input character, or multiple input characters per glyph). This is useful to explicitly manipulate the exact output positions of characters, e.g. relative to a reference output device.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def combinedJustify(self, aNextLayouts: 'typing.Tuple[XTextLayout, ...]', nSize: float) -> float:
        """
        Justify a number of text layouts to the given size.
        
        This method can be used to combine the layout of a text line into a single justification run. This is e.g. useful if the line consists of several text portions (e.g. because of different fonts or colors), but it is desirable to spread the available space more globally across the different layout objects. If, for example, one layout object contains significantly more whitespace or Kashidas than the rest, this method can assign proportionally more space to this layout object.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getBaselineOffset(self) -> float:
        """
        This method yields the baseline offset.
        
        This method returns the baseline offset for this layout object, either measured from the top or the left edge, depending on the writing direction (horizontally or vertically). Since rendering this layout via XCanvas.drawTextLayout() outputs relative to the layout object's baseline, this method can be used to e.g. output relative to the left, top edge.
        """
    def getCaret(self, nInsertionIndex: int, bExcludeLigatures: bool) -> 'Caret_9b480ab5':
        """
        This method converts an insertion index to a caret.
        
        This method generates caret information for a given insertion point in the layout text.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getFont(self) -> 'XCanvasFont_e3380d11':
        """
        Request the associated font for this layout.
        """
    def getMainTextDirection(self) -> int:
        """
        This method returns the main writing direction.
        
        This method returns the main writing direction of this layout, i.e. either LEFT_TO_RIGHT or RIGHT_TO_LEFT.
        """
    def getNextInsertionIndex(self, nStartIndex: int, nCaretAdvancement: int, bExcludeLigatures: bool) -> int:
        """
        This method calculates a new insertion index.
        
        This method calculates a new insertion index, given a start index and the number of characters to skip. This is most useful for caret traveling.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getText(self) -> 'StringContext_d50e22':
        """
        Request the text this layout contains.
        """
    def getTextHit(self, aHitPoint: 'RealPoint2D_d6e70c78') -> 'TextHit_b25d0b90':
        """
        This method determines the hit position in the text.
        
        This method determines the index of the character hit at the specified position (in font coordinate space).
        """
    def justify(self, nSize: float) -> float:
        """
        Justify the text to the given size.
        
        This method is the core of the XTextLayout interface, because it layouts the text in a typographically correct way into the available space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def queryInkMeasures(self) -> 'typing.Tuple[RealRectangle2D_d9b0e03, ...]':
        """
        Query the ink bounding boxes for every glyph in the layouted text.
        
        Ink, or tight bounding boxes in this case means that for e.g. an \"a\", the bounding box for the XPolyPolygon2D describing the glyph \"a\" is returned, not the logical dimensions of the character in the font.
        """
    def queryLogicalAdvancements(self) -> 'typing.Tuple[float, ...]':
        """
        Query the advancements for every character in the input string.
        
        This method returns a sequence of advancements, one for each character in the input string (not for every glyph. There might be multiple glyphs per input character, or multiple input characters per glyph).
        
        An advancement value is the distance of the glyph to the beginning edge, which is left for LTR text and is right for RTL text. The maximum of the advancements can be deemed as the width of the whole text layout.
        
        This method can be used to query for the layout's default advancements, which can subsequently be changed and applied to the layout via XTextLayout.applyLogicalAdvancements().
        """
    def queryLogicalHighlighting(self, nStartIndex: int, nEndIndex: int) -> 'XPolyPolygon2D_e1b0e20':
        """
        This method generates a highlight polygon.
        
        This method generates a highlighting polygon from two insertion indices. This polygon will not always be visually continuous, if e.g. the text direction changes in the middle of the selection, the might be parts visually between start and end position that are not selected.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def queryMeasures(self) -> 'typing.Tuple[RealRectangle2D_d9b0e03, ...]':
        """
        Query the logical bounding boxes of every character in the given text string.
        
        Logical bounding boxes means the space that the font allocates for the given character, which, e.g. for a \".\", might be significantly broader than the bounds returned via XTextLayout.queryInkMeasures().
        """
    def queryTextBounds(self) -> 'RealRectangle2D_d9b0e03':
        """
        Query the overall bounding box of the text.
        
        This method is similar to XTextLayout.queryTextMeasures(), only that the overall bounds are returned by this method.
        """
    def queryTextShapes(self) -> 'typing.Tuple[XPolyPolygon2D_e1b0e20, ...]':
        """
        Extract the polygonal shapes of the layouted text.
        
        Each glyph is represented by a separate XPolyPolygon2D in the returned sequence.
        """
    def queryVisualHighlighting(self, nStartIndex: int, nEndIndex: int) -> 'XPolyPolygon2D_e1b0e20':
        """
        This method generates a highlight polygon.
        
        This method generates a highlighting polygon from two insertion indices. This polygon will be visually continuous, i.e. will not have non-highlighted text in between.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """

